@@ -66,6 +66,14 @@ STRUCTURE = Nav(
 						Nav(lazy_gettext("Pour aller plus loin")),
 					],
 				),
+				Nav(
+					lazy_gettext("Complexité et Machine de Turing"),
+					index=True,
+					children=[
+						Nav(lazy_gettext("Jeu, Complexité et Résolution")),
+						Nav(lazy_gettext("Magic et Complexité")),
+					],
+				),
 				Nav(lazy_gettext("Construire un deck")),
 				Nav(lazy_gettext("Mélanger un deck")),
 			],
@@ -80,6 +88,7 @@ STRUCTURE = Nav(
 				Nav(lazy_gettext("Golos, Tireless Pilgrim")),
 				Nav(lazy_gettext("Kelsien, the Plague")),
 				Nav(lazy_gettext("Kess, Dissident Mage")),
+				Nav(lazy_gettext("Orvar, the All-Form")),
 				Nav(lazy_gettext("Rowan and Will Kenrith")),
 				Nav(lazy_gettext("The Gitrog Monster")),
 				Nav(lazy_gettext("Titania, Protector of Argoth")),
